@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import plistlib
 
 from benedict.serializers.abstract import AbstractSerializer
@@ -12,7 +10,7 @@ class PListSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(PListSerializer, self).__init__(
+        super().__init__(
             extensions=[
                 "plist",
             ],
