@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import xmltodict
 
 from benedict.serializers.abstract import AbstractSerializer
@@ -11,7 +9,7 @@ class XMLSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(XMLSerializer, self).__init__(
+        super().__init__(
             extensions=[
                 "xml",
             ],
